==> beast_0.7.4.orig.tar.bz2: beast-0.7.4/bse/bsegentypes.c <==




GType BSE_TYPE_ID (GslDataCacheRequest) = 0;

GType BSE_TYPE_ID (GslVorbisCutterMode) = 0;

GType BSE_TYPE_ID (BseMusicalTuningType) = 0;

GType BSE_TYPE_ID (BseMidiSignalType) = 0;

GType BSE_TYPE_ID (BseMidiControlType) = 0;

GType BSE_TYPE_ID (BseMidiChannelEventType) = 0;

GType BSE_TYPE_ID (BseMsgType) = 0;

GType BSE_TYPE_ID (BseThreadState) = 0;

GType BSE_TYPE_ID (BseExportNodeType) = 0;

GType BSE_TYPE_ID (BseBiquadFilterType) = 0;

GType BSE_TYPE_ID (BseBiquadFilterNorm) = 0;

GType BSE_TYPE_ID (BseRegistrationType) = 0;

GType BSE_TYPE_ID (BseInterpolType) = 0;

GType BSE_TYPE_ID (BseLoopType) = 0;

GType BSE_TYPE_ID (BseMagicFlags) = 0;

GType BSE_TYPE_ID (BseErrorType) = 0;

GType BSE_TYPE_ID (BseTimeRangeType) = 0;

GType BSE_TYPE_ID (BseMidiEventType) = 0;

GType BSE_TYPE_ID (BseProjectState) = 0;

GType BSE_TYPE_ID (BseStandardOscWaveType) = 0;

GType BSE_TYPE_ID (BseMidiDecoderState) = 0;




/*
 * Generated data (by mktypes.pl --interns --export-proto)
 */

/* --- bsebus.c --- */
extern BSE_BUILTIN_PROTO (BseBus);
GType bse_type_builtin_id_BseBus = 0;

/* --- bsebiquadfilter.c --- */
extern BSE_BUILTIN_PROTO (BseBiquadFilter);
GType bse_type_builtin_id_BseBiquadFilter = 0;

/* --- bseconstant.c --- */
extern BSE_BUILTIN_PROTO (BseConstant);
GType bse_type_builtin_id_BseConstant = 0;

/* --- bsecontainer.c --- */
extern BSE_BUILTIN_PROTO (BseContainer);
GType bse_type_builtin_id_BseContainer = 0;

/* --- bsecontextmerger.c --- */
extern BSE_BUILTIN_PROTO (BseContextMerger);
GType bse_type_builtin_id_BseContextMerger = 0;

/* --- bsedatapocket.c --- */
extern BSE_BUILTIN_PROTO (BseDataPocket);
GType bse_type_builtin_id_BseDataPocket = 0;

/* --- bseeditablesample.c --- */
extern BSE_BUILTIN_PROTO (BseEditableSample);
GType bse_type_builtin_id_BseEditableSample = 0;

/* --- bseitem.c --- */
extern BSE_BUILTIN_PROTO (BseItem);
GType bse_type_builtin_id_BseItem = 0;

/* --- bsejanitor.c --- */
extern BSE_BUILTIN_PROTO (BseJanitor);
GType bse_type_builtin_id_BseJanitor = 0;

/* --- bseladspa.cc --- */
extern BSE_BUILTIN_PROTO (BseLadspaPlugin);
GType bse_type_builtin_id_BseLadspaPlugin = 0;

/* --- bsemidicontroller.c --- */
extern BSE_BUILTIN_PROTO (BseMidiController);
GType bse_type_builtin_id_BseMidiController = 0;

/* --- bsemididevice.c --- */
extern BSE_BUILTIN_PROTO (BseMidiDevice);
GType bse_type_builtin_id_BseMidiDevice = 0;

/* --- bsedevice.c --- */
extern BSE_BUILTIN_PROTO (BseDevice);
GType bse_type_builtin_id_BseDevice = 0;

/* --- bsemididevice-null.c --- */
extern BSE_BUILTIN_PROTO (BseMidiDeviceNULL);
GType bse_type_builtin_id_BseMidiDeviceNULL = 0;

/* --- bsemididevice-oss.c --- */
extern BSE_BUILTIN_PROTO (BseMidiDeviceOSS);
GType bse_type_builtin_id_BseMidiDeviceOSS = 0;

/* --- bsemidinotifier.c --- */
extern BSE_BUILTIN_PROTO (BseMidiNotifier);
GType bse_type_builtin_id_BseMidiNotifier = 0;

/* --- bsemidisynth.c --- */
extern BSE_BUILTIN_PROTO (BseMidiSynth);
GType bse_type_builtin_id_BseMidiSynth = 0;

/* --- bseobject.c --- */
extern BSE_BUILTIN_PROTO (BseObject);
GType bse_type_builtin_id_BseObject = 0;

/* --- bsepart.c --- */
extern BSE_BUILTIN_PROTO (BsePart);
GType bse_type_builtin_id_BsePart = 0;

/* --- bsepcminput.c --- */
extern BSE_BUILTIN_PROTO (BsePcmInput);
GType bse_type_builtin_id_BsePcmInput = 0;

/* --- bsepcmoutput.c --- */
extern BSE_BUILTIN_PROTO (BsePcmOutput);
GType bse_type_builtin_id_BsePcmOutput = 0;

/* --- bsepcmdevice.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDevice);
GType bse_type_builtin_id_BsePcmDevice = 0;

/* --- bsepcmdevice-oss.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDeviceOSS);
GType bse_type_builtin_id_BsePcmDeviceOSS = 0;

/* --- bsepcmdevice-null.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDeviceNull);
GType bse_type_builtin_id_BsePcmDeviceNull = 0;

/* --- bseplugin.c --- */
extern BSE_BUILTIN_PROTO (BsePlugin);
GType bse_type_builtin_id_BsePlugin = 0;

/* --- bseproject.c --- */
extern BSE_BUILTIN_PROTO (BseProject);
GType bse_type_builtin_id_BseProject = 0;

/* --- bseserver.c --- */
extern BSE_BUILTIN_PROTO (BseServer);
GType bse_type_builtin_id_BseServer = 0;

/* --- bsesnet.c --- */
extern BSE_BUILTIN_PROTO (BseSNet);
GType bse_type_builtin_id_BseSNet = 0;

/* --- bsesnooper.c --- */
extern BSE_BUILTIN_PROTO (BseSnooper);
GType bse_type_builtin_id_BseSnooper = 0;

/* --- bsesong.c --- */
extern BSE_BUILTIN_PROTO (BseSong);
GType bse_type_builtin_id_BseSong = 0;

/* --- bsesource.c --- */
extern BSE_BUILTIN_PROTO (BseSource);
GType bse_type_builtin_id_BseSource = 0;

/* --- bsestandardosc.c --- */
extern BSE_BUILTIN_PROTO (BseStandardOsc);
GType bse_type_builtin_id_BseStandardOsc = 0;

/* --- bsestorage.c --- */
extern BSE_BUILTIN_PROTO (BseStorage);
GType bse_type_builtin_id_BseStorage = 0;

/* --- bseinstrumentoutput.c --- */
extern BSE_BUILTIN_PROTO (BseInstrumentOutput);
GType bse_type_builtin_id_BseInstrumentOutput = 0;

/* --- bsesubiport.c --- */
extern BSE_BUILTIN_PROTO (BseSubIPort);
GType bse_type_builtin_id_BseSubIPort = 0;

/* --- bseinstrumentinput.c --- */
extern BSE_BUILTIN_PROTO (BseInstrumentInput);
GType bse_type_builtin_id_BseInstrumentInput = 0;

/* --- bsesuboport.c --- */
extern BSE_BUILTIN_PROTO (BseSubOPort);
GType bse_type_builtin_id_BseSubOPort = 0;

/* --- bsesubsynth.c --- */
extern BSE_BUILTIN_PROTO (BseSubSynth);
GType bse_type_builtin_id_BseSubSynth = 0;

/* --- bsesuper.c --- */
extern BSE_BUILTIN_PROTO (BseSuper);
GType bse_type_builtin_id_BseSuper = 0;

/* --- bsetrack.c --- */
extern BSE_BUILTIN_PROTO (BseTrack);
GType bse_type_builtin_id_BseTrack = 0;

/* --- bsemidivoice.c --- */
extern BSE_BUILTIN_PROTO (BseMidiVoiceInput);
GType bse_type_builtin_id_BseMidiVoiceInput = 0;

/* --- bsemidivoice.c --- */
extern BSE_BUILTIN_PROTO (BseMidiVoiceSwitch);
GType bse_type_builtin_id_BseMidiVoiceSwitch = 0;

/* --- bsewave.c --- */
extern BSE_BUILTIN_PROTO (BseWave);
GType bse_type_builtin_id_BseWave = 0;

/* --- bsewaveosc.c --- */
extern BSE_BUILTIN_PROTO (BseWaveOsc);
GType bse_type_builtin_id_BseWaveOsc = 0;

/* --- bsecsynth.c --- */
extern BSE_BUILTIN_PROTO (BseCSynth);
GType bse_type_builtin_id_BseCSynth = 0;

/* --- bsewaverepo.c --- */
extern BSE_BUILTIN_PROTO (BseWaveRepo);
GType bse_type_builtin_id_BseWaveRepo = 0;

/* --- bseladspamodule.c --- */
extern BSE_BUILTIN_PROTO (BseLadspaModule);
GType bse_type_builtin_id_BseLadspaModule = 0;

/* --- bsepcmwriter.c --- */
extern BSE_BUILTIN_PROTO (BsePcmWriter);
GType bse_type_builtin_id_BsePcmWriter = 0;

/* --- bsemidiinput.c --- */
extern BSE_BUILTIN_PROTO (BseMidiInput);
GType bse_type_builtin_id_BseMidiInput = 0;

/*
 * Generated data ends here
 */

==> beast_0.7.6.orig.tar.bz2: beast-0.7.6/bse/bsegentypes.c <==




GType BSE_TYPE_ID (GslDataCacheRequest) = 0;

GType BSE_TYPE_ID (GslVorbisCutterMode) = 0;

GType BSE_TYPE_ID (BseMusicalTuningType) = 0;

GType BSE_TYPE_ID (BseMidiSignalType) = 0;

GType BSE_TYPE_ID (BseMidiControlType) = 0;

GType BSE_TYPE_ID (BseMidiChannelEventType) = 0;

GType BSE_TYPE_ID (BseMsgType) = 0;

GType BSE_TYPE_ID (BseThreadState) = 0;

GType BSE_TYPE_ID (BseExportNodeType) = 0;

GType BSE_TYPE_ID (BseBiquadFilterType) = 0;

GType BSE_TYPE_ID (BseBiquadFilterNorm) = 0;

GType BSE_TYPE_ID (BseRegistrationType) = 0;

GType BSE_TYPE_ID (BseInterpolType) = 0;

GType BSE_TYPE_ID (BseLoopType) = 0;

GType BSE_TYPE_ID (BseMagicFlags) = 0;

GType BSE_TYPE_ID (BseErrorType) = 0;

GType BSE_TYPE_ID (BseTimeRangeType) = 0;

GType BSE_TYPE_ID (BseMidiEventType) = 0;

GType BSE_TYPE_ID (BseProjectState) = 0;

GType BSE_TYPE_ID (BseStandardOscWaveType) = 0;

GType BSE_TYPE_ID (BseMidiDecoderState) = 0;




/*
 * Generated data (by mktypes.pl --interns --export-proto)
 */

/* --- bsebus.cc --- */
extern BSE_BUILTIN_PROTO (BseBus);
GType bse_type_builtin_id_BseBus = 0;

/* --- bsebiquadfilter.cc --- */
extern BSE_BUILTIN_PROTO (BseBiquadFilter);
GType bse_type_builtin_id_BseBiquadFilter = 0;

/* --- bseconstant.cc --- */
extern BSE_BUILTIN_PROTO (BseConstant);
GType bse_type_builtin_id_BseConstant = 0;

/* --- bsecontainer.cc --- */
extern BSE_BUILTIN_PROTO (BseContainer);
GType bse_type_builtin_id_BseContainer = 0;

/* --- bsecontextmerger.cc --- */
extern BSE_BUILTIN_PROTO (BseContextMerger);
GType bse_type_builtin_id_BseContextMerger = 0;

/* --- bsedatapocket.cc --- */
extern BSE_BUILTIN_PROTO (BseDataPocket);
GType bse_type_builtin_id_BseDataPocket = 0;

/* --- bseeditablesample.cc --- */
extern BSE_BUILTIN_PROTO (BseEditableSample);
GType bse_type_builtin_id_BseEditableSample = 0;

/* --- bseitem.cc --- */
extern BSE_BUILTIN_PROTO (BseItem);
GType bse_type_builtin_id_BseItem = 0;

/* --- bsejanitor.cc --- */
extern BSE_BUILTIN_PROTO (BseJanitor);
GType bse_type_builtin_id_BseJanitor = 0;

/* --- bseladspa.cc --- */
extern BSE_BUILTIN_PROTO (BseLadspaPlugin);
GType bse_type_builtin_id_BseLadspaPlugin = 0;

/* --- bsemidicontroller.cc --- */
extern BSE_BUILTIN_PROTO (BseMidiController);
GType bse_type_builtin_id_BseMidiController = 0;

/* --- bsemididevice.cc --- */
extern BSE_BUILTIN_PROTO (BseMidiDevice);
GType bse_type_builtin_id_BseMidiDevice = 0;

/* --- bsedevice.cc --- */
extern BSE_BUILTIN_PROTO (BseDevice);
GType bse_type_builtin_id_BseDevice = 0;

/* --- bsemididevice-null.cc --- */
extern BSE_BUILTIN_PROTO (BseMidiDeviceNULL);
GType bse_type_builtin_id_BseMidiDeviceNULL = 0;

/* --- bsemididevice-oss.cc --- */
extern BSE_BUILTIN_PROTO (BseMidiDeviceOSS);
GType bse_type_builtin_id_BseMidiDeviceOSS = 0;

/* --- bsemidinotifier.c --- */
extern BSE_BUILTIN_PROTO (BseMidiNotifier);
GType bse_type_builtin_id_BseMidiNotifier = 0;

/* --- bsemidisynth.c --- */
extern BSE_BUILTIN_PROTO (BseMidiSynth);
GType bse_type_builtin_id_BseMidiSynth = 0;

/* --- bseobject.c --- */
extern BSE_BUILTIN_PROTO (BseObject);
GType bse_type_builtin_id_BseObject = 0;

/* --- bsepart.c --- */
extern BSE_BUILTIN_PROTO (BsePart);
GType bse_type_builtin_id_BsePart = 0;

/* --- bsepcminput.c --- */
extern BSE_BUILTIN_PROTO (BsePcmInput);
GType bse_type_builtin_id_BsePcmInput = 0;

/* --- bsepcmoutput.c --- */
extern BSE_BUILTIN_PROTO (BsePcmOutput);
GType bse_type_builtin_id_BsePcmOutput = 0;

/* --- bsepcmdevice.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDevice);
GType bse_type_builtin_id_BsePcmDevice = 0;

/* --- bsepcmdevice-oss.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDeviceOSS);
GType bse_type_builtin_id_BsePcmDeviceOSS = 0;

/* --- bsepcmdevice-null.c --- */
extern BSE_BUILTIN_PROTO (BsePcmDeviceNull);
GType bse_type_builtin_id_BsePcmDeviceNull = 0;

/* --- bseplugin.c --- */
extern BSE_BUILTIN_PROTO (BsePlugin);
GType bse_type_builtin_id_BsePlugin = 0;

/* --- bseproject.c --- */
extern BSE_BUILTIN_PROTO (BseProject);
GType bse_type_builtin_id_BseProject = 0;

/* --- bseserver.c --- */
extern BSE_BUILTIN_PROTO (BseServer);
GType bse_type_builtin_id_BseServer = 0;

/* --- bsesnet.c --- */
extern BSE_BUILTIN_PROTO (BseSNet);
GType bse_type_builtin_id_BseSNet = 0;

/* --- bsesnooper.c --- */
extern BSE_BUILTIN_PROTO (BseSnooper);
GType bse_type_builtin_id_BseSnooper = 0;

/* --- bsesong.c --- */
extern BSE_BUILTIN_PROTO (BseSong);
GType bse_type_builtin_id_BseSong = 0;

/* --- bsesource.c --- */
extern BSE_BUILTIN_PROTO (BseSource);
GType bse_type_builtin_id_BseSource = 0;

/* --- bsestandardosc.c --- */
extern BSE_BUILTIN_PROTO (BseStandardOsc);
GType bse_type_builtin_id_BseStandardOsc = 0;

/* --- bsestorage.c --- */
extern BSE_BUILTIN_PROTO (BseStorage);
GType bse_type_builtin_id_BseStorage = 0;

/* --- bseinstrumentoutput.cc --- */
extern BSE_BUILTIN_PROTO (BseInstrumentOutput);
GType bse_type_builtin_id_BseInstrumentOutput = 0;

/* --- bsesubiport.c --- */
extern BSE_BUILTIN_PROTO (BseSubIPort);
GType bse_type_builtin_id_BseSubIPort = 0;

/* --- bseinstrumentinput.cc --- */
extern BSE_BUILTIN_PROTO (BseInstrumentInput);
GType bse_type_builtin_id_BseInstrumentInput = 0;

/* --- bsesuboport.c --- */
extern BSE_BUILTIN_PROTO (BseSubOPort);
GType bse_type_builtin_id_BseSubOPort = 0;

/* --- bsesubsynth.c --- */
extern BSE_BUILTIN_PROTO (BseSubSynth);
GType bse_type_builtin_id_BseSubSynth = 0;

/* --- bsesuper.c --- */
extern BSE_BUILTIN_PROTO (BseSuper);
GType bse_type_builtin_id_BseSuper = 0;

/* --- bsetrack.c --- */
extern BSE_BUILTIN_PROTO (BseTrack);
GType bse_type_builtin_id_BseTrack = 0;

/* --- bsemidivoice.c --- */
extern BSE_BUILTIN_PROTO (BseMidiVoiceInput);
GType bse_type_builtin_id_BseMidiVoiceInput = 0;

/* --- bsemidivoice.c --- */
extern BSE_BUILTIN_PROTO (BseMidiVoiceSwitch);
GType bse_type_builtin_id_BseMidiVoiceSwitch = 0;

/* --- bsewave.c --- */
extern BSE_BUILTIN_PROTO (BseWave);
GType bse_type_builtin_id_BseWave = 0;

/* --- bsewaveosc.c --- */
extern BSE_BUILTIN_PROTO (BseWaveOsc);
GType bse_type_builtin_id_BseWaveOsc = 0;

/* --- bsecsynth.cc --- */
extern BSE_BUILTIN_PROTO (BseCSynth);
GType bse_type_builtin_id_BseCSynth = 0;

/* --- bsewaverepo.c --- */
extern BSE_BUILTIN_PROTO (BseWaveRepo);
GType bse_type_builtin_id_BseWaveRepo = 0;

/* --- bseladspamodule.cc --- */
extern BSE_BUILTIN_PROTO (BseLadspaModule);
GType bse_type_builtin_id_BseLadspaModule = 0;

/* --- bsepcmwriter.c --- */
extern BSE_BUILTIN_PROTO (BsePcmWriter);
GType bse_type_builtin_id_BsePcmWriter = 0;

/* --- bsemidiinput.cc --- */
extern BSE_BUILTIN_PROTO (BseMidiInput);
GType bse_type_builtin_id_BseMidiInput = 0;

/*
 * Generated data ends here
 */
